@@ -1,9 +1,7 @@
-import datetime
-
 import pygame
 
 from .colors import BLACK
-import flask
+
 
 class Page(object):
 
@@ -154,28 +152,7 @@ class GUI(object):
             touch.on_release = handle_touches
             touch.on_move = handle_touches
 
-        app = flask.Flask(__name__)
-
-        @app.route('/post', methods=['POST'])
-        def post():
-            message = flask.request.form['message']
-            now = datetime.datetime.now().replace(microsecond=0).time()
-            print(f'[{now.isoformat()}] : {message}')
-
-        @app.route('/stream')
-        def stream():
-            return flask.Response(event_stream(),
-                                  mimetype="text/event-stream")
-
-        def event_stream():
-            now = datetime.datetime.now().replace(microsecond=0).time()
-            message = f"TIME {now}"
-            yield f'data: {message}\n\n'
-
         try:
-            app.debug = True
-            app.run(threaded=True)
-
             while self._running:
                 time = pygame.time.get_ticks()
                 # deltaTime in seconds.
@@ -194,6 +171,7 @@ class GUI(object):
             self.reset_display()
             print("Stopping touchscreen thread...")
             self._touchscreen.stop()
+
             print("Exiting GUI...")
             exit()
 
