@@ -324,20 +324,25 @@ class GraphButton(Button):
             return
 
         values = self.update(graph_size[0] - 2)
+        print(f"### RENDERING {self.label!r} ===================")
+        print(f"### GRAPH ASK FOR {graph_size[0] - 2}, GOT {len(values)}")
         min_val = 9999
         max_val = -9999
         for entry in values:
             data = entry["data"]
             min_val = entry.get("min", min(min_val, min(data)))
             max_val = entry.get("min", max(max_val, max(data)))
+        print(f"### MIN {min_val}, MAX {max_val}")
 
         range = max_val - min_val
         if range < 1:
             min_val -= 1
             max_val += 1
             range = 2
+        print(f"### RANGE {range}")
 
         for entry in values:
+            print(f"### => {entry}")
             color = entry["color"]
             data = entry["data"]
 
@@ -350,25 +355,31 @@ class GraphButton(Button):
             prev_x = graph_pos[0]
             for val in data:
                 x = prev_x + 1
+                print(f"### SCALE {val}...")
                 y = scale_y_value(val)
+                print(f"### ... TO {y}")
                 pygame.draw.line(surface, color, (prev_x, prev_y), (x, y), 2)
                 prev_x = x
                 prev_y = y
 
-            text = self.graph_font.render(snapped_value_string(data[-1], 0.1),
-                                          1,
-                                          color)
-            textpos = text.get_rect()
-            textpos.right = (self.x + self.w) - self.LABEL_INSET
-            # The text tracks the graph line, unless it's outside the
-            # extents, then we clamp it to inside.
-            if (prev_y + textpos.h + self.LABEL_INSET) > (self.y + self.h):
-                textpos.bottom = prev_y - self.LABEL_INSET
-            elif (prev_y - textpos.h - self.LABEL_INSET) < (self.y):
-                textpos.top = prev_y + self.LABEL_INSET
-            else:
-                textpos.centery = prev_y
-            surface.blit(text, textpos)
+            if len(data) > 0:
+                print(f"### RENDER LAST VALUE")
+                print(f"### OF {data[-1]}")
+
+                text = self.graph_font.render(snapped_value_string(data[-1], 0.1),
+                                              1,
+                                              color)
+                textpos = text.get_rect()
+                textpos.right = (self.x + self.w) - self.LABEL_INSET
+                # The text tracks the graph line, unless it's outside the
+                # extents, then we clamp it to inside.
+                if (prev_y + textpos.h + self.LABEL_INSET) > (self.y + self.h):
+                    textpos.bottom = prev_y - self.LABEL_INSET
+                elif (prev_y - textpos.h - self.LABEL_INSET) < (self.y):
+                    textpos.top = prev_y + self.LABEL_INSET
+                else:
+                    textpos.centery = prev_y
+                surface.blit(text, textpos)
 
 
 class IDynamicWidget(IWidget):
